<?php
    /*------------------------------------------------------------------------
    # cblikes.php - Stand Alone Like Component
    # ------------------------------------------------------------------------
    # author    Joomboxr Team
    # copyright Copyright (C) 2010-2016 joomboxr.com. All Rights Reserved.
    # license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
    # Support Forum   http://joomboxr.com/product/cbx-like/
    -------------------------------------------------------------------------*/

    // No direct access to this file
    defined('_JEXEC') or die('Restricted access');

    class CBLikeModelCBXLikes extends JModelList {

        /**
         * Constructor.
         *
         * @param   array $config An optional associative array of configuration settings.
         *
         * @since   1.6
         * @see     JController
         */
        public function __construct($config = array()) {
            if (empty($config['filter_fields'])) {
                $config['filter_fields'] = array(
                    'id', 'a.id',
                    'extensionname', 'a.extensionname',
                    'itemid', 'a.itemid',
                    'likecount', 'a.likecount',
                    'guestlike', 'a.guestlike',
                    'viewname', 'a.viewname',

                );
            }

            parent::__construct($config);
        }

        /**
         * Method to build an SQL query to load the list data.
         *
         * @return    string    An SQL query
         */
        protected function getListQuery() {
            // Create a new query object.
            $db    = JFactory::getDBO();
            $query = $db->getQuery(true);

            $query->select(
                $this->getState(
                    'list.select','a.id,a.extensionname, a.itemid, a.likecount, a.guestlike, a.viewname'
                )
            );
            $query->from('#__cbliker_likesummary a');





            // Filter by extensions
            $extension_components = $this->getState('filter.extension_components');
            $extension_views = $this->getState('filter.extension_views');

            if($extension_components != ''){
                $query->where('a.extensionname = "'.$extension_components.'"');
                if($extension_views != ''){
                    $query->where('a.viewname = "'.$extension_views.'"');
                }
            }



            // Filter by search in title.
            $search = $this->getState('filter.search');

            if (!empty($search))
            {
                if (stripos($search, 'id:') === 0)
                {
                    $query->where('a.id = ' . (int) substr($search, 3));
                }
                else
                {
                    $search = $db->quote('%' . $db->escape($search, true) . '%');
                    $query->where('(a.viewname LIKE ' . $search . ' OR a.extensionname LIKE ' . $search .')');
                }
            }

            // Add the list ordering clause.
            $orderCol  = $this->state->get('list.ordering');
            $orderDirn = $this->state->get('list.direction');

            $query->order($db->escape($orderCol . ' ' . $orderDirn));

            //echo "<pre>";var_dump($query);echo "</pre>";

            return $query;
        }

        protected function populateState($ordering = null, $direction = null) {



            // Load the filter state.
            $search = $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
            $this->setState('filter.search', $search);

            $extension_components = $this->getUserStateFromRequest($this->context . '.filter.extension_components', 'filter_extension_components', '');
            $this->setState('filter.extension_components', $extension_components);

            $extension_views = $this->getUserStateFromRequest($this->context . '.filter.extension_views', 'filter_extension_views', '');
            $this->setState('filter.extension_views', $extension_views);

            // List state information.
            parent::populateState('a.id', 'desc');
        }

        protected function _getList($query, $limitstart = 0, $limit = 0) {
            $ordering = $this->getState('list.ordering');
            $query->order($this->_db->quoteName($ordering) . ' ' . $this->getState('list.direction'));

            $result = parent::_getList($query, $limitstart, $limit);


            return $result;
        }

        public function getItems()
        {
            $items = parent::getItems();

            return $items;
        }
    }